@@ -1,7 +1,7 @@
 '''
 # `nomad_acl_role`
 
-Refer to the Terraform Registory for docs: [`nomad_acl_role`](https://www.terraform.io/docs/providers/nomad/r/acl_role).
+Refer to the Terraform Registory for docs: [`nomad_acl_role`](https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs/resources/acl_role).
 '''
 import abc
 import builtins
@@ -26,7 +26,7 @@ class AclRole(
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-nomad.aclRole.AclRole",
 ):
-    '''Represents a {@link https://www.terraform.io/docs/providers/nomad/r/acl_role nomad_acl_role}.'''
+    '''Represents a {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs/resources/acl_role nomad_acl_role}.'''
 
     def __init__(
         self,
@@ -34,25 +34,25 @@ class AclRole(
         id_: builtins.str,
         *,
         name: builtins.str,
-        policy: typing.Union[typing.Sequence[typing.Union["AclRolePolicy", typing.Dict[builtins.str, typing.Any]]], _cdktf_9a9027ec.IResolvable],
+        policy: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["AclRolePolicy", typing.Dict[builtins.str, typing.Any]]]],
         description: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
         connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
-        count: typing.Optional[jsii.Number] = None,
+        count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
         depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
         for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
         lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
         provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
         provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
-        '''Create a new {@link https://www.terraform.io/docs/providers/nomad/r/acl_role nomad_acl_role} Resource.
+        '''Create a new {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs/resources/acl_role nomad_acl_role} Resource.
 
         :param scope: The scope in which to define this construct.
         :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
-        :param name: Unique name for this ACL role. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad/r/acl_role#name AclRole#name}
-        :param policy: policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad/r/acl_role#policy AclRole#policy}
-        :param description: Description for this ACL role. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad/r/acl_role#description AclRole#description}
-        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad/r/acl_role#id AclRole#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param name: Unique name for this ACL role. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs/resources/acl_role#name AclRole#name}
+        :param policy: policy block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs/resources/acl_role#policy AclRole#policy}
+        :param description: Description for this ACL role. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs/resources/acl_role#description AclRole#description}
+        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs/resources/acl_role#id AclRole#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         :param connection: 
         :param count: 
         :param depends_on: 
@@ -81,10 +81,34 @@ class AclRole(
 
         jsii.create(self.__class__, self, [scope, id_, config])
 
+    @jsii.member(jsii_name="generateConfigForImport")
+    @builtins.classmethod
+    def generate_config_for_import(
+        cls,
+        scope: _constructs_77d1e7e8.Construct,
+        import_to_id: builtins.str,
+        import_from_id: builtins.str,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    ) -> _cdktf_9a9027ec.ImportableResource:
+        '''Generates CDKTF code for importing a AclRole resource upon running "cdktf plan ".
+
+        :param scope: The scope in which to define this construct.
+        :param import_to_id: The construct id used in the generated config for the AclRole to import.
+        :param import_from_id: The id of the existing AclRole that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs/resources/acl_role#import import section} in the documentation of this resource for the id to use
+        :param provider: ? Optional instance of the provider where the AclRole to import is found.
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__940f0d704c2375bdb6542d499b0ebdb4e17fb2d068fb4851978e527a5f38bc7a)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument import_to_id", value=import_to_id, expected_type=type_hints["import_to_id"])
+            check_type(argname="argument import_from_id", value=import_from_id, expected_type=type_hints["import_from_id"])
+            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
+        return typing.cast(_cdktf_9a9027ec.ImportableResource, jsii.sinvoke(cls, "generateConfigForImport", [scope, import_to_id, import_from_id, provider]))
+
     @jsii.member(jsii_name="putPolicy")
     def put_policy(
         self,
-        value: typing.Union[typing.Sequence[typing.Union["AclRolePolicy", typing.Dict[builtins.str, typing.Any]]], _cdktf_9a9027ec.IResolvable],
+        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["AclRolePolicy", typing.Dict[builtins.str, typing.Any]]]],
     ) -> None:
         '''
         :param value: -
@@ -135,8 +159,8 @@ class AclRole(
     @jsii.member(jsii_name="policyInput")
     def policy_input(
         self,
-    ) -> typing.Optional[typing.Union[typing.List["AclRolePolicy"], _cdktf_9a9027ec.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[typing.List["AclRolePolicy"], _cdktf_9a9027ec.IResolvable]], jsii.get(self, "policyInput"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["AclRolePolicy"]]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["AclRolePolicy"]]], jsii.get(self, "policyInput"))
 
     @builtins.property
     @jsii.member(jsii_name="description")
@@ -197,14 +221,14 @@ class AclRoleConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         self,
         *,
         connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
-        count: typing.Optional[jsii.Number] = None,
+        count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
         depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
         for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
         lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
         provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
         provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         name: builtins.str,
-        policy: typing.Union[typing.Sequence[typing.Union["AclRolePolicy", typing.Dict[builtins.str, typing.Any]]], _cdktf_9a9027ec.IResolvable],
+        policy: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["AclRolePolicy", typing.Dict[builtins.str, typing.Any]]]],
         description: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -216,10 +240,10 @@ class AclRoleConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         :param lifecycle: 
         :param provider: 
         :param provisioners: 
-        :param name: Unique name for this ACL role. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad/r/acl_role#name AclRole#name}
-        :param policy: policy block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad/r/acl_role#policy AclRole#policy}
-        :param description: Description for this ACL role. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad/r/acl_role#description AclRole#description}
-        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad/r/acl_role#id AclRole#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param name: Unique name for this ACL role. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs/resources/acl_role#name AclRole#name}
+        :param policy: policy block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs/resources/acl_role#policy AclRole#policy}
+        :param description: Description for this ACL role. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs/resources/acl_role#description AclRole#description}
+        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs/resources/acl_role#id AclRole#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         '''
         if isinstance(lifecycle, dict):
             lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
@@ -270,12 +294,14 @@ class AclRoleConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
-    def count(self) -> typing.Optional[jsii.Number]:
+    def count(
+        self,
+    ) -> typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("count")
-        return typing.cast(typing.Optional[jsii.Number], result)
+        return typing.cast(typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]], result)
 
     @builtins.property
     def depends_on(
@@ -325,7 +351,7 @@ class AclRoleConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def name(self) -> builtins.str:
         '''Unique name for this ACL role.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad/r/acl_role#name AclRole#name}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs/resources/acl_role#name AclRole#name}
         '''
         result = self._values.get("name")
         assert result is not None, "Required property 'name' is missing"
@@ -334,27 +360,27 @@ class AclRoleConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     @builtins.property
     def policy(
         self,
-    ) -> typing.Union[typing.List["AclRolePolicy"], _cdktf_9a9027ec.IResolvable]:
+    ) -> typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["AclRolePolicy"]]:
         '''policy block.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad/r/acl_role#policy AclRole#policy}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs/resources/acl_role#policy AclRole#policy}
         '''
         result = self._values.get("policy")
         assert result is not None, "Required property 'policy' is missing"
-        return typing.cast(typing.Union[typing.List["AclRolePolicy"], _cdktf_9a9027ec.IResolvable], result)
+        return typing.cast(typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["AclRolePolicy"]], result)
 
     @builtins.property
     def description(self) -> typing.Optional[builtins.str]:
         '''Description for this ACL role.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad/r/acl_role#description AclRole#description}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs/resources/acl_role#description AclRole#description}
         '''
         result = self._values.get("description")
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def id(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad/r/acl_role#id AclRole#id}.
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs/resources/acl_role#id AclRole#id}.
 
         Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
         If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
@@ -382,7 +408,7 @@ class AclRoleConfig(_cdktf_9a9027ec.TerraformMetaArguments):
 class AclRolePolicy:
     def __init__(self, *, name: builtins.str) -> None:
         '''
-        :param name: The name of the ACL policy to link. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad/r/acl_role#name AclRole#name}
+        :param name: The name of the ACL policy to link. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs/resources/acl_role#name AclRole#name}
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__a091de4c363c10633aceeaf1802821125a53573ba932314f6cbb7044e6d684b0)
@@ -395,7 +421,7 @@ class AclRolePolicy:
     def name(self) -> builtins.str:
         '''The name of the ACL policy to link.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad/r/acl_role#name AclRole#name}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs/resources/acl_role#name AclRole#name}
         '''
         result = self._values.get("name")
         assert result is not None, "Required property 'name' is missing"
@@ -489,13 +515,13 @@ class AclRolePolicyList(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[typing.List[AclRolePolicy], _cdktf_9a9027ec.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[typing.List[AclRolePolicy], _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[AclRolePolicy]]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[AclRolePolicy]]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[typing.List[AclRolePolicy], _cdktf_9a9027ec.IResolvable]],
+        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[AclRolePolicy]]],
     ) -> None:
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__b3fae82f51199a8f5e69f61891dc71a8dd97064b7b828785c98538cabe82950e)
@@ -550,13 +576,13 @@ class AclRolePolicyOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[AclRolePolicy, _cdktf_9a9027ec.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[AclRolePolicy, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, AclRolePolicy]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, AclRolePolicy]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[AclRolePolicy, _cdktf_9a9027ec.IResolvable]],
+        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, AclRolePolicy]],
     ) -> None:
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__9e83c9af5a93b485a4f2dff1a71fa0e019ff08c4d259f413c8af9c288b79a199)
@@ -579,11 +605,11 @@ def _typecheckingstub__4976db7c26d1e52c2ae1294e0d1d6c1419cf2ccd917add0067cc668f3
     id_: builtins.str,
     *,
     name: builtins.str,
-    policy: typing.Union[typing.Sequence[typing.Union[AclRolePolicy, typing.Dict[builtins.str, typing.Any]]], _cdktf_9a9027ec.IResolvable],
+    policy: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[AclRolePolicy, typing.Dict[builtins.str, typing.Any]]]],
     description: typing.Optional[builtins.str] = None,
     id: typing.Optional[builtins.str] = None,
     connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
-    count: typing.Optional[jsii.Number] = None,
+    count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
     depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
     for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
     lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
@@ -593,8 +619,17 @@ def _typecheckingstub__4976db7c26d1e52c2ae1294e0d1d6c1419cf2ccd917add0067cc668f3
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__940f0d704c2375bdb6542d499b0ebdb4e17fb2d068fb4851978e527a5f38bc7a(
+    scope: _constructs_77d1e7e8.Construct,
+    import_to_id: builtins.str,
+    import_from_id: builtins.str,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__5f939ee24f50565ed8502684476148cc05621e8d318c00ba3d30453fa8aecfcc(
-    value: typing.Union[typing.Sequence[typing.Union[AclRolePolicy, typing.Dict[builtins.str, typing.Any]]], _cdktf_9a9027ec.IResolvable],
+    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[AclRolePolicy, typing.Dict[builtins.str, typing.Any]]]],
 ) -> None:
     """Type checking stubs"""
     pass
@@ -620,14 +655,14 @@ def _typecheckingstub__c9003ab52903ced6e032b63f6e8e719f8cce1be5a4422099f3958dc47
 def _typecheckingstub__00a078397c19bf37a1ce639f57206f0924696d5c214414806605104c17fff840(
     *,
     connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
-    count: typing.Optional[jsii.Number] = None,
+    count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
     depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
     for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
     lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
     provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
     provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     name: builtins.str,
-    policy: typing.Union[typing.Sequence[typing.Union[AclRolePolicy, typing.Dict[builtins.str, typing.Any]]], _cdktf_9a9027ec.IResolvable],
+    policy: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[AclRolePolicy, typing.Dict[builtins.str, typing.Any]]]],
     description: typing.Optional[builtins.str] = None,
     id: typing.Optional[builtins.str] = None,
 ) -> None:
@@ -674,7 +709,7 @@ def _typecheckingstub__35e24c7329e7d4297348ec92e5931ff155e1b99adc93d00005d17311b
     pass
 
 def _typecheckingstub__b3fae82f51199a8f5e69f61891dc71a8dd97064b7b828785c98538cabe82950e(
-    value: typing.Optional[typing.Union[typing.List[AclRolePolicy], _cdktf_9a9027ec.IResolvable]],
+    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[AclRolePolicy]]],
 ) -> None:
     """Type checking stubs"""
     pass
@@ -695,7 +730,7 @@ def _typecheckingstub__e86f0973282350f402710ba27b001822b4b49ccebc20dc57a7b1c9a66
     pass
 
 def _typecheckingstub__9e83c9af5a93b485a4f2dff1a71fa0e019ff08c4d259f413c8af9c288b79a199(
-    value: typing.Optional[typing.Union[AclRolePolicy, _cdktf_9a9027ec.IResolvable]],
+    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, AclRolePolicy]],
 ) -> None:
     """Type checking stubs"""
     pass
