@@ -1,7 +1,7 @@
 '''
 # `provider`
 
-Refer to the Terraform Registory for docs: [`nomad`](https://www.terraform.io/docs/providers/nomad).
+Refer to the Terraform Registory for docs: [`nomad`](https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs).
 '''
 import abc
 import builtins
@@ -26,7 +26,7 @@ class NomadProvider(
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-nomad.provider.NomadProvider",
 ):
-    '''Represents a {@link https://www.terraform.io/docs/providers/nomad nomad}.'''
+    '''Represents a {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs nomad}.'''
 
     def __init__(
         self,
@@ -47,27 +47,29 @@ class NomadProvider(
         key_pem: typing.Optional[builtins.str] = None,
         region: typing.Optional[builtins.str] = None,
         secret_id: typing.Optional[builtins.str] = None,
+        skip_verify: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         vault_token: typing.Optional[builtins.str] = None,
     ) -> None:
-        '''Create a new {@link https://www.terraform.io/docs/providers/nomad nomad} Resource.
+        '''Create a new {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs nomad} Resource.
 
         :param scope: The scope in which to define this construct.
         :param id: The scoped construct ID. Must be unique amongst siblings in the same scope
-        :param address: URL of the root of the target Nomad agent. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#address NomadProvider#address}
-        :param alias: Alias name. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#alias NomadProvider#alias}
-        :param ca_file: A path to a PEM-encoded certificate authority used to verify the remote agent's certificate. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#ca_file NomadProvider#ca_file}
-        :param ca_pem: PEM-encoded certificate authority used to verify the remote agent's certificate. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#ca_pem NomadProvider#ca_pem}
-        :param cert_file: A path to a PEM-encoded certificate provided to the remote agent; requires use of key_file or key_pem. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#cert_file NomadProvider#cert_file}
-        :param cert_pem: PEM-encoded certificate provided to the remote agent; requires use of key_file or key_pem. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#cert_pem NomadProvider#cert_pem}
-        :param consul_token: Consul token to validate Consul Connect Service Identity policies specified in the job file. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#consul_token NomadProvider#consul_token}
-        :param headers: headers block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#headers NomadProvider#headers}
-        :param http_auth: HTTP basic auth configuration. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#http_auth NomadProvider#http_auth}
-        :param ignore_env_vars: A set of environment variables that are ignored by the provider when configuring the Nomad API client. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#ignore_env_vars NomadProvider#ignore_env_vars}
-        :param key_file: A path to a PEM-encoded private key, required if cert_file or cert_pem is specified. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#key_file NomadProvider#key_file}
-        :param key_pem: PEM-encoded private key, required if cert_file or cert_pem is specified. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#key_pem NomadProvider#key_pem}
-        :param region: Region of the target Nomad agent. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#region NomadProvider#region}
-        :param secret_id: ACL token secret for API requests. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#secret_id NomadProvider#secret_id}
-        :param vault_token: Vault token if policies are specified in the job file. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#vault_token NomadProvider#vault_token}
+        :param address: URL of the root of the target Nomad agent. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#address NomadProvider#address}
+        :param alias: Alias name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#alias NomadProvider#alias}
+        :param ca_file: A path to a PEM-encoded certificate authority used to verify the remote agent's certificate. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#ca_file NomadProvider#ca_file}
+        :param ca_pem: PEM-encoded certificate authority used to verify the remote agent's certificate. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#ca_pem NomadProvider#ca_pem}
+        :param cert_file: A path to a PEM-encoded certificate provided to the remote agent; requires use of key_file or key_pem. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#cert_file NomadProvider#cert_file}
+        :param cert_pem: PEM-encoded certificate provided to the remote agent; requires use of key_file or key_pem. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#cert_pem NomadProvider#cert_pem}
+        :param consul_token: Consul token to validate Consul Connect Service Identity policies specified in the job file. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#consul_token NomadProvider#consul_token}
+        :param headers: headers block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#headers NomadProvider#headers}
+        :param http_auth: HTTP basic auth configuration. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#http_auth NomadProvider#http_auth}
+        :param ignore_env_vars: A set of environment variables that are ignored by the provider when configuring the Nomad API client. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#ignore_env_vars NomadProvider#ignore_env_vars}
+        :param key_file: A path to a PEM-encoded private key, required if cert_file or cert_pem is specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#key_file NomadProvider#key_file}
+        :param key_pem: PEM-encoded private key, required if cert_file or cert_pem is specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#key_pem NomadProvider#key_pem}
+        :param region: Region of the target Nomad agent. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#region NomadProvider#region}
+        :param secret_id: ACL token secret for API requests. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#secret_id NomadProvider#secret_id}
+        :param skip_verify: Skip TLS verification on client side. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#skip_verify NomadProvider#skip_verify}
+        :param vault_token: Vault token if policies are specified in the job file. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#vault_token NomadProvider#vault_token}
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__fa1135b3e0a6e5d3f7edfef684226a9a3ae7c144ae366e8b37d5ae425d916fff)
@@ -88,11 +90,36 @@ class NomadProvider(
             key_pem=key_pem,
             region=region,
             secret_id=secret_id,
+            skip_verify=skip_verify,
             vault_token=vault_token,
         )
 
         jsii.create(self.__class__, self, [scope, id, config])
 
+    @jsii.member(jsii_name="generateConfigForImport")
+    @builtins.classmethod
+    def generate_config_for_import(
+        cls,
+        scope: _constructs_77d1e7e8.Construct,
+        import_to_id: builtins.str,
+        import_from_id: builtins.str,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    ) -> _cdktf_9a9027ec.ImportableResource:
+        '''Generates CDKTF code for importing a NomadProvider resource upon running "cdktf plan ".
+
+        :param scope: The scope in which to define this construct.
+        :param import_to_id: The construct id used in the generated config for the NomadProvider to import.
+        :param import_from_id: The id of the existing NomadProvider that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#import import section} in the documentation of this resource for the id to use
+        :param provider: ? Optional instance of the provider where the NomadProvider to import is found.
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__1fe3e6bb963e9fe03449bc0ac46c50f7523599db7df7556b66b2f81ef712e9be)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument import_to_id", value=import_to_id, expected_type=type_hints["import_to_id"])
+            check_type(argname="argument import_from_id", value=import_from_id, expected_type=type_hints["import_from_id"])
+            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
+        return typing.cast(_cdktf_9a9027ec.ImportableResource, jsii.sinvoke(cls, "generateConfigForImport", [scope, import_to_id, import_from_id, provider]))
+
     @jsii.member(jsii_name="resetAlias")
     def reset_alias(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetAlias", []))
@@ -145,6 +172,10 @@ class NomadProvider(
     def reset_secret_id(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetSecretId", []))
 
+    @jsii.member(jsii_name="resetSkipVerify")
+    def reset_skip_verify(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetSkipVerify", []))
+
     @jsii.member(jsii_name="resetVaultToken")
     def reset_vault_token(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetVaultToken", []))
@@ -232,6 +263,13 @@ class NomadProvider(
     def secret_id_input(self) -> typing.Optional[builtins.str]:
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "secretIdInput"))
 
+    @builtins.property
+    @jsii.member(jsii_name="skipVerifyInput")
+    def skip_verify_input(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "skipVerifyInput"))
+
     @builtins.property
     @jsii.member(jsii_name="vaultTokenInput")
     def vault_token_input(self) -> typing.Optional[builtins.str]:
@@ -415,6 +453,23 @@ class NomadProvider(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "secretId", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="skipVerify")
+    def skip_verify(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "skipVerify"))
+
+    @skip_verify.setter
+    def skip_verify(
+        self,
+        value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]],
+    ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__24301788f020684a7feadc62b6c52e1d9000b49e1582ca38fae3a11048fbc5b0)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "skipVerify", value)
+
     @builtins.property
     @jsii.member(jsii_name="vaultToken")
     def vault_token(self) -> typing.Optional[builtins.str]:
@@ -446,6 +501,7 @@ class NomadProvider(
         "key_pem": "keyPem",
         "region": "region",
         "secret_id": "secretId",
+        "skip_verify": "skipVerify",
         "vault_token": "vaultToken",
     },
 )
@@ -467,24 +523,26 @@ class NomadProviderConfig:
         key_pem: typing.Optional[builtins.str] = None,
         region: typing.Optional[builtins.str] = None,
         secret_id: typing.Optional[builtins.str] = None,
+        skip_verify: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         vault_token: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
-        :param address: URL of the root of the target Nomad agent. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#address NomadProvider#address}
-        :param alias: Alias name. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#alias NomadProvider#alias}
-        :param ca_file: A path to a PEM-encoded certificate authority used to verify the remote agent's certificate. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#ca_file NomadProvider#ca_file}
-        :param ca_pem: PEM-encoded certificate authority used to verify the remote agent's certificate. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#ca_pem NomadProvider#ca_pem}
-        :param cert_file: A path to a PEM-encoded certificate provided to the remote agent; requires use of key_file or key_pem. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#cert_file NomadProvider#cert_file}
-        :param cert_pem: PEM-encoded certificate provided to the remote agent; requires use of key_file or key_pem. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#cert_pem NomadProvider#cert_pem}
-        :param consul_token: Consul token to validate Consul Connect Service Identity policies specified in the job file. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#consul_token NomadProvider#consul_token}
-        :param headers: headers block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#headers NomadProvider#headers}
-        :param http_auth: HTTP basic auth configuration. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#http_auth NomadProvider#http_auth}
-        :param ignore_env_vars: A set of environment variables that are ignored by the provider when configuring the Nomad API client. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#ignore_env_vars NomadProvider#ignore_env_vars}
-        :param key_file: A path to a PEM-encoded private key, required if cert_file or cert_pem is specified. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#key_file NomadProvider#key_file}
-        :param key_pem: PEM-encoded private key, required if cert_file or cert_pem is specified. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#key_pem NomadProvider#key_pem}
-        :param region: Region of the target Nomad agent. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#region NomadProvider#region}
-        :param secret_id: ACL token secret for API requests. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#secret_id NomadProvider#secret_id}
-        :param vault_token: Vault token if policies are specified in the job file. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#vault_token NomadProvider#vault_token}
+        :param address: URL of the root of the target Nomad agent. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#address NomadProvider#address}
+        :param alias: Alias name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#alias NomadProvider#alias}
+        :param ca_file: A path to a PEM-encoded certificate authority used to verify the remote agent's certificate. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#ca_file NomadProvider#ca_file}
+        :param ca_pem: PEM-encoded certificate authority used to verify the remote agent's certificate. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#ca_pem NomadProvider#ca_pem}
+        :param cert_file: A path to a PEM-encoded certificate provided to the remote agent; requires use of key_file or key_pem. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#cert_file NomadProvider#cert_file}
+        :param cert_pem: PEM-encoded certificate provided to the remote agent; requires use of key_file or key_pem. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#cert_pem NomadProvider#cert_pem}
+        :param consul_token: Consul token to validate Consul Connect Service Identity policies specified in the job file. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#consul_token NomadProvider#consul_token}
+        :param headers: headers block. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#headers NomadProvider#headers}
+        :param http_auth: HTTP basic auth configuration. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#http_auth NomadProvider#http_auth}
+        :param ignore_env_vars: A set of environment variables that are ignored by the provider when configuring the Nomad API client. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#ignore_env_vars NomadProvider#ignore_env_vars}
+        :param key_file: A path to a PEM-encoded private key, required if cert_file or cert_pem is specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#key_file NomadProvider#key_file}
+        :param key_pem: PEM-encoded private key, required if cert_file or cert_pem is specified. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#key_pem NomadProvider#key_pem}
+        :param region: Region of the target Nomad agent. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#region NomadProvider#region}
+        :param secret_id: ACL token secret for API requests. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#secret_id NomadProvider#secret_id}
+        :param skip_verify: Skip TLS verification on client side. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#skip_verify NomadProvider#skip_verify}
+        :param vault_token: Vault token if policies are specified in the job file. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#vault_token NomadProvider#vault_token}
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__e759273490438086fe5dd3d88c084b63217b1cc6e133fcd010a5f3e4c7a37ada)
@@ -502,6 +560,7 @@ class NomadProviderConfig:
             check_type(argname="argument key_pem", value=key_pem, expected_type=type_hints["key_pem"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
             check_type(argname="argument secret_id", value=secret_id, expected_type=type_hints["secret_id"])
+            check_type(argname="argument skip_verify", value=skip_verify, expected_type=type_hints["skip_verify"])
             check_type(argname="argument vault_token", value=vault_token, expected_type=type_hints["vault_token"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
             "address": address,
@@ -532,6 +591,8 @@ class NomadProviderConfig:
             self._values["region"] = region
         if secret_id is not None:
             self._values["secret_id"] = secret_id
+        if skip_verify is not None:
+            self._values["skip_verify"] = skip_verify
         if vault_token is not None:
             self._values["vault_token"] = vault_token
 
@@ -539,7 +600,7 @@ class NomadProviderConfig:
     def address(self) -> builtins.str:
         '''URL of the root of the target Nomad agent.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#address NomadProvider#address}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#address NomadProvider#address}
         '''
         result = self._values.get("address")
         assert result is not None, "Required property 'address' is missing"
@@ -549,7 +610,7 @@ class NomadProviderConfig:
     def alias(self) -> typing.Optional[builtins.str]:
         '''Alias name.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#alias NomadProvider#alias}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#alias NomadProvider#alias}
         '''
         result = self._values.get("alias")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -558,7 +619,7 @@ class NomadProviderConfig:
     def ca_file(self) -> typing.Optional[builtins.str]:
         '''A path to a PEM-encoded certificate authority used to verify the remote agent's certificate.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#ca_file NomadProvider#ca_file}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#ca_file NomadProvider#ca_file}
         '''
         result = self._values.get("ca_file")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -567,7 +628,7 @@ class NomadProviderConfig:
     def ca_pem(self) -> typing.Optional[builtins.str]:
         '''PEM-encoded certificate authority used to verify the remote agent's certificate.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#ca_pem NomadProvider#ca_pem}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#ca_pem NomadProvider#ca_pem}
         '''
         result = self._values.get("ca_pem")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -576,7 +637,7 @@ class NomadProviderConfig:
     def cert_file(self) -> typing.Optional[builtins.str]:
         '''A path to a PEM-encoded certificate provided to the remote agent; requires use of key_file or key_pem.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#cert_file NomadProvider#cert_file}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#cert_file NomadProvider#cert_file}
         '''
         result = self._values.get("cert_file")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -585,7 +646,7 @@ class NomadProviderConfig:
     def cert_pem(self) -> typing.Optional[builtins.str]:
         '''PEM-encoded certificate provided to the remote agent; requires use of key_file or key_pem.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#cert_pem NomadProvider#cert_pem}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#cert_pem NomadProvider#cert_pem}
         '''
         result = self._values.get("cert_pem")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -594,7 +655,7 @@ class NomadProviderConfig:
     def consul_token(self) -> typing.Optional[builtins.str]:
         '''Consul token to validate Consul Connect Service Identity policies specified in the job file.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#consul_token NomadProvider#consul_token}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#consul_token NomadProvider#consul_token}
         '''
         result = self._values.get("consul_token")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -605,7 +666,7 @@ class NomadProviderConfig:
     ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["NomadProviderHeaders"]]]:
         '''headers block.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#headers NomadProvider#headers}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#headers NomadProvider#headers}
         '''
         result = self._values.get("headers")
         return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["NomadProviderHeaders"]]], result)
@@ -614,7 +675,7 @@ class NomadProviderConfig:
     def http_auth(self) -> typing.Optional[builtins.str]:
         '''HTTP basic auth configuration.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#http_auth NomadProvider#http_auth}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#http_auth NomadProvider#http_auth}
         '''
         result = self._values.get("http_auth")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -625,7 +686,7 @@ class NomadProviderConfig:
     ) -> typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]]:
         '''A set of environment variables that are ignored by the provider when configuring the Nomad API client.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#ignore_env_vars NomadProvider#ignore_env_vars}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#ignore_env_vars NomadProvider#ignore_env_vars}
         '''
         result = self._values.get("ignore_env_vars")
         return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]], result)
@@ -634,7 +695,7 @@ class NomadProviderConfig:
     def key_file(self) -> typing.Optional[builtins.str]:
         '''A path to a PEM-encoded private key, required if cert_file or cert_pem is specified.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#key_file NomadProvider#key_file}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#key_file NomadProvider#key_file}
         '''
         result = self._values.get("key_file")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -643,7 +704,7 @@ class NomadProviderConfig:
     def key_pem(self) -> typing.Optional[builtins.str]:
         '''PEM-encoded private key, required if cert_file or cert_pem is specified.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#key_pem NomadProvider#key_pem}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#key_pem NomadProvider#key_pem}
         '''
         result = self._values.get("key_pem")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -652,7 +713,7 @@ class NomadProviderConfig:
     def region(self) -> typing.Optional[builtins.str]:
         '''Region of the target Nomad agent.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#region NomadProvider#region}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#region NomadProvider#region}
         '''
         result = self._values.get("region")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -661,16 +722,27 @@ class NomadProviderConfig:
     def secret_id(self) -> typing.Optional[builtins.str]:
         '''ACL token secret for API requests.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#secret_id NomadProvider#secret_id}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#secret_id NomadProvider#secret_id}
         '''
         result = self._values.get("secret_id")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def skip_verify(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        '''Skip TLS verification on client side.
+
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#skip_verify NomadProvider#skip_verify}
+        '''
+        result = self._values.get("skip_verify")
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
+
     @builtins.property
     def vault_token(self) -> typing.Optional[builtins.str]:
         '''Vault token if policies are specified in the job file.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#vault_token NomadProvider#vault_token}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#vault_token NomadProvider#vault_token}
         '''
         result = self._values.get("vault_token")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -695,8 +767,8 @@ class NomadProviderConfig:
 class NomadProviderHeaders:
     def __init__(self, *, name: builtins.str, value: builtins.str) -> None:
         '''
-        :param name: The header name. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#name NomadProvider#name}
-        :param value: The header value. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#value NomadProvider#value}
+        :param name: The header name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#name NomadProvider#name}
+        :param value: The header value. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#value NomadProvider#value}
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__55e77394e5bf2f9bd34a37f003dbe588118fddb6f74338ed48dcede78167deb3)
@@ -711,7 +783,7 @@ class NomadProviderHeaders:
     def name(self) -> builtins.str:
         '''The header name.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#name NomadProvider#name}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#name NomadProvider#name}
         '''
         result = self._values.get("name")
         assert result is not None, "Required property 'name' is missing"
@@ -721,7 +793,7 @@ class NomadProviderHeaders:
     def value(self) -> builtins.str:
         '''The header value.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/nomad#value NomadProvider#value}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.0.0/docs#value NomadProvider#value}
         '''
         result = self._values.get("value")
         assert result is not None, "Required property 'value' is missing"
@@ -765,11 +837,21 @@ def _typecheckingstub__fa1135b3e0a6e5d3f7edfef684226a9a3ae7c144ae366e8b37d5ae425
     key_pem: typing.Optional[builtins.str] = None,
     region: typing.Optional[builtins.str] = None,
     secret_id: typing.Optional[builtins.str] = None,
+    skip_verify: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     vault_token: typing.Optional[builtins.str] = None,
 ) -> None:
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__1fe3e6bb963e9fe03449bc0ac46c50f7523599db7df7556b66b2f81ef712e9be(
+    scope: _constructs_77d1e7e8.Construct,
+    import_to_id: builtins.str,
+    import_from_id: builtins.str,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__0beabfec8d7dd5d694d2cef5d7bc866119587940ba297f965ed9e5822f413b7a(
     value: typing.Optional[builtins.str],
 ) -> None:
@@ -854,6 +936,12 @@ def _typecheckingstub__a02d46d72fb1046bdbb99d51171a00c00913f2085971c13e6a975aa87
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__24301788f020684a7feadc62b6c52e1d9000b49e1582ca38fae3a11048fbc5b0(
+    value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__6c35027298099735fca65479f06bd9ef7c18a82b71e2e6c73f48e0b6327262c6(
     value: typing.Optional[builtins.str],
 ) -> None:
@@ -876,6 +964,7 @@ def _typecheckingstub__e759273490438086fe5dd3d88c084b63217b1cc6e133fcd010a5f3e4c
     key_pem: typing.Optional[builtins.str] = None,
     region: typing.Optional[builtins.str] = None,
     secret_id: typing.Optional[builtins.str] = None,
+    skip_verify: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     vault_token: typing.Optional[builtins.str] = None,
 ) -> None:
     """Type checking stubs"""
